/*
 * MainFrame.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
*/

package eu.europa.echa.reach.preregistration.examples.preregcheck;

import java.awt.Color;
import java.io.File;
import java.net.URL;
import java.util.Properties;
import javax.swing.ImageIcon;
import javax.swing.JFileChooser;
import javax.swing.UIManager;
import javax.swing.text.BadLocationException;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyleContext;
import javax.swing.text.StyledDocument;
import org.apache.log4j.Logger;

/**
 *
 * @author  Csk Gbor
 */
public class MainFrame extends javax.swing.JFrame {
    
    private static final Logger logger = Logger.getLogger(MainFrame.class);
    
    public MainFrame() {
        setLookAndFeel();
        initComponents();
        
        URL iconURL = getClass().getResource("/eu/europa/echa/reach/preregistration/examples/preregcheck/images/check.png");
        if (iconURL != null) setIconImage(new ImageIcon(iconURL).getImage());
        
        fileNamesTextField.setText(Application.getPreferences().getProperty("fileNames", ""));

        getRootPane().setDefaultButton(checkButton);
        
        StyledDocument doc = messages.getStyledDocument();
        Style def = StyleContext.getDefaultStyleContext().getStyle(StyleContext.DEFAULT_STYLE);
        StyleConstants.setFontFamily(def, "Monospaced");
        StyleConstants.setFontSize(def, 12);//pixels
        
        Style blackStyle = doc.addStyle("black", def);
        StyleConstants.setForeground(blackStyle , Color.BLACK);
        
        Style blueStyle = doc.addStyle("blue", def);
        StyleConstants.setForeground(blueStyle , Color.BLUE);
        
        Style greenStyle = doc.addStyle("green", def);
        StyleConstants.setForeground(greenStyle , Color.GREEN);

        Style orangeStyle = doc.addStyle("orange", def);
        StyleConstants.setForeground(orangeStyle , Color.ORANGE);
        
        Style redStyle = doc.addStyle("red", def);
        StyleConstants.setForeground(redStyle , Color.RED);
    }
    
    private void selectFile() {
        File defaultDirectory = null;
        try {
            defaultDirectory = new File(fileNamesTextField.getText().split(File.pathSeparator)[0]);
        } catch (Exception ex) {
        }
        JFileChooser fileChooser = new JFileChooser(defaultDirectory);
        fileChooser.setDialogType(JFileChooser.CUSTOM_DIALOG);
        fileChooser.setAcceptAllFileFilterUsed(true);
        fileChooser.setFileSelectionMode(JFileChooser.FILES_AND_DIRECTORIES);
        fileChooser.setMultiSelectionEnabled(true);
        //fileChooser.setSelectedFiles();
        if (fileChooser.showDialog(this, "Select") == JFileChooser.APPROVE_OPTION) {
            File[] files = fileChooser.getSelectedFiles();
            StringBuffer fileNames = new StringBuffer();
            
            for (File file: files) {
                if (fileNames.length() > 0) {
                    fileNames.append(File.pathSeparatorChar);
                }
                fileNames.append(file.getAbsolutePath());
            }
            
            fileNamesTextField.setText(fileNames.toString());
        }
    }
    
    private void setLookAndFeel() {
        final String LOOKANDFEEL_METAL = "javax.swing.plaf.metal.MetalLookAndFeel";
        final String LOOKANDFEEL_MOTIF = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";
        final String LOOKANDFEEL_WINDOWS = "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";
        
        // some users haven't upgraded the OS yet
        // let's not disturb them with a different UI; they have enaugh trouble
        if (System.getProperty("os.name").contains("Windows")) {
            try {
                UIManager.setLookAndFeel(LOOKANDFEEL_WINDOWS);
                //SwingUtilities.updateComponentTreeUI(this);
            } catch (Exception ex) {
                logger.error(ex);
            }
        }
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        jLabel1 = new javax.swing.JLabel();
        fileNamesTextField = new javax.swing.JTextField();
        browseButton = new javax.swing.JButton();
        jScrollPane1 = new javax.swing.JScrollPane();
        messages = new javax.swing.JTextPane();
        closeButton = new javax.swing.JButton();
        clearButton = new javax.swing.JButton();
        checkButton = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setTitle("Pre-registration schema check");
        setCursor(new java.awt.Cursor(java.awt.Cursor.DEFAULT_CURSOR));
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosed(java.awt.event.WindowEvent evt) {
                onWindowClosed(evt);
            }
        });

        jLabel1.setText("File(s) / Directory(s)");

        browseButton.setText("Open");
        browseButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                selectFile(evt);
            }
        });

        messages.setEditable(false);
        jScrollPane1.setViewportView(messages);

        closeButton.setText("Close");
        closeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exit(evt);
            }
        });

        clearButton.setText("Clear");
        clearButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearMessages(evt);
            }
        });

        checkButton.setText("Check");
        checkButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                Validate(evt);
            }
        });

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                    .add(org.jdesktop.layout.GroupLayout.LEADING, jScrollPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 980, Short.MAX_VALUE)
                    .add(org.jdesktop.layout.GroupLayout.LEADING, layout.createSequentialGroup()
                        .add(jLabel1)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(fileNamesTextField, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 835, Short.MAX_VALUE)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(browseButton, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 39, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                    .add(layout.createSequentialGroup()
                        .add(checkButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(clearButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(closeButton)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel1)
                    .add(browseButton)
                    .add(fileNamesTextField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jScrollPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 341, Short.MAX_VALUE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(closeButton)
                    .add(clearButton)
                    .add(checkButton))
                .addContainerGap())
        );
        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void onWindowClosed(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_onWindowClosed
        Application.getPreferences().setProperty("fileNames", fileNamesTextField.getText());
        Application.storePreferences();
    }//GEN-LAST:event_onWindowClosed
    
    private void exit(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exit
        this.dispose();
    }//GEN-LAST:event_exit
    
    private void clearMessages(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearMessages
        final StyledDocument doc = messages.getStyledDocument();
        try {
            doc.remove(0, doc.getLength());
        } catch (BadLocationException ex) {
            logger.error("StyledDocument.remove() failed", ex);
        }
    }//GEN-LAST:event_clearMessages
    
    private void Validate(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_Validate
        checkButton.setEnabled(false);
        clearButton.setEnabled(false);
        closeButton.setEnabled(false);
        
        final String fileDirName = fileNamesTextField.getText();
        
        Thread validatorThread = new Thread(new Runnable() {
            public void run() {
                Validator validator = new Validator();
                validator.setMessageWriter(new Validator.MessageWriter() {
                    public void write(final String message,final Color color) {
                        final StyledDocument doc = messages.getStyledDocument();
                        java.awt.EventQueue.invokeLater(new Runnable() {
                            public void run() {
                                Style style = null;
                                if (Color.BLACK.equals(color)) {
                                    style=doc.getStyle("black");
                                } else if (Color.BLUE.equals(color)) {
                                    style=doc.getStyle("blue");
                                }else if (Color.GREEN.equals(color)) {
                                    style=doc.getStyle("green");
                                } else if (Color.ORANGE.equals(color)) {
                                    style=doc.getStyle("orange");
                                } else if (Color.RED.equals(color)) {
                                    style=doc.getStyle("red");
                                }
                                try {
                                    doc.insertString(doc.getLength(), message, style);
                                } catch (BadLocationException ex) {
                                    logger.error("Writing into StyledDocument failed", ex);
                                }
                            }
                        });
                    }
                });
                
                validator.validate(fileDirName.split(File.pathSeparator));
                
                // enable buttons when the work is done
                java.awt.EventQueue.invokeLater(new Runnable() {
                    public void run() {
                        checkButton.setEnabled(true);
                        clearButton.setEnabled(true);
                        closeButton.setEnabled(true);
                    }
                });
            }
        });
        validatorThread.start();
        
        
    }//GEN-LAST:event_Validate
        
    private void selectFile(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_selectFile
        // call another method, because the form designer might delete this code
        // in that case I have to rewrite it from scratch
        selectFile();
    }//GEN-LAST:event_selectFile
    
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton browseButton;
    private javax.swing.JButton checkButton;
    private javax.swing.JButton clearButton;
    private javax.swing.JButton closeButton;
    private javax.swing.JTextField fileNamesTextField;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTextPane messages;
    // End of variables declaration//GEN-END:variables
    
}
