/*
 * Application.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration.examples.preregdb;

import eu.europa.echa.reach.preregistration.PreRegistration;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.Driver;
import java.sql.DriverManager;
import java.util.Properties;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;

/**
 *
 * @author Csk Gbor
 */
public class Application {
    
    private static final Logger logger = Logger.getLogger(Application.class);
    
    public Application() {
    }
    
    public static void main(String[] args) {
        
        //configure default log4j logging
        BasicConfigurator.configure();
        Logger.getRootLogger().setLevel(Level.INFO);
        
        logger.debug("Application Start");
        
        try {
            Properties properties = new Properties();
            {
                InputStream inputStream = ClassLoader.getSystemResourceAsStream("preregdb.properties");
                if (inputStream == null) {
                    logger.error("Properties cannot be loaded");
                    throw new NullPointerException("Properties cannot be loaded");
                } else {
                    properties.load(inputStream);
                }
            }
            
            //Connect to the database
            Connection connection = null;
            
            String jdbcDriverClass = properties.getProperty("jdbc.driver.class");
            logger.debug("Loading driver: " + jdbcDriverClass);
            Driver driver = (Driver) Class.forName(jdbcDriverClass).newInstance();
            DriverManager.registerDriver(driver);
            
            String dbUrl = properties.getProperty("jdbc.connection.url");
            String dbUser = properties.getProperty("jdbc.connection.user");
            String dbPassword = properties.getProperty("jdbc.connection.password");

            logger.debug("Connecting to database: " + dbUrl);
            connection = DriverManager.getConnection(dbUrl, dbUser, dbPassword);
            logger.info("Connected to database: " + dbUrl);
            
            try {
                PreRegistration preRegistration = new PreRegistration(properties);
                preRegistration.loadSubstanceIdentities(connection);
                preRegistration.serialize(properties.getProperty("output.file", "preregistration"));
            } finally {
                if (connection != null) {
                    connection.close();
                    connection = null;
                    logger.debug("Db connection closed");
                }
            }
        } catch (Exception ex) {
            logger.error("Uncaught Exception: ", ex);
        }
        logger.debug("Application Exit");
    }
    
}
