/*
 * ContactInfo.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration;

import eu.europa.echa.reach.preregistration.xml.XMLWriter;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.SQLWarning;
import org.apache.log4j.Logger;
import org.xml.sax.SAXException;

/**
 *
 * @author Csk Gbor
 */
public class ContactInfo {
    
    private static final Logger logger = Logger.getLogger(PreRegistration.class);
    
    public String phone; //*
    public String fax;
    public String mobile;
    public String email; //*
    public String webSite;
    public PostalAddress postalAddress;
    
    public ContactInfo() {
    }
    
    public void serialize(XMLWriter xmlWriter) throws SerializationException {
        try {
            final String CONTACTINFORMATION = "contactInformation";
            xmlWriter.startElement(XMLWriter.NS.CTI, CONTACTINFORMATION);
            {
                final String PHONE = "phone";
                xmlWriter.startElement(XMLWriter.NS.CTI, PHONE);
                xmlWriter.writeElement(XMLWriter.NS.CTI, "formattedNumber", phone);
                xmlWriter.endElement(XMLWriter.NS.CTI, PHONE);
            }
            if (fax != null) {
                final String FAX = "fax";
                xmlWriter.startElement(XMLWriter.NS.CTI, FAX);
                xmlWriter.writeElement(XMLWriter.NS.CTI, "formattedNumber", fax);
                xmlWriter.endElement(XMLWriter.NS.CTI, FAX);
            }
            if (mobile != null) {
                final String MOBILE = "mobile";
                xmlWriter.startElement(XMLWriter.NS.CTI, MOBILE);
                xmlWriter.writeElement(XMLWriter.NS.CTI, "formattedNumber", mobile);
                xmlWriter.endElement(XMLWriter.NS.CTI, MOBILE);
            }
            xmlWriter.writeElement(XMLWriter.NS.CTI, "email", email);
            if (webSite != null) xmlWriter.writeElement(XMLWriter.NS.CTI, "webSite", webSite);
            if (postalAddress != null) postalAddress.serialize(xmlWriter);
            xmlWriter.endElement(XMLWriter.NS.CTI, CONTACTINFORMATION);
        } catch (SAXException ex) {
            throw new SerializationException(ex);
        }
    }
    
    //TODO Remove this
    private static void handleWarnings(SQLWarning warning) {
        if (warning != null) {
            logger.warn("SQL warning: " + warning.getMessage() + " code: " + warning.getErrorCode());
            // handle linked warnings
            handleWarnings(warning.getNextWarning());
        }
    }
    
}

class PostalAddress {
    public String street1; //*
    public String street2;
    public String zipCode; //*
    public String city;
    public String state;
    public String country; //*
    public String envelopeAddress;
    
    public PostalAddress() {
    }
    
    public void serialize(XMLWriter xmlWriter) throws SerializationException {
        try {
            final String POSTALADDRESS = "postalAddress";
            xmlWriter.startElement(XMLWriter.NS.CTI, POSTALADDRESS);
            xmlWriter.writeElement(XMLWriter.NS.CTI, "street1", street1);
            if (street2 != null) xmlWriter.writeElement(XMLWriter.NS.CTI, "street2", street2);
            xmlWriter.writeElement(XMLWriter.NS.CTI, "zipCode", zipCode);
            if (city != null) xmlWriter.writeElement(XMLWriter.NS.CTI, "city", city);
            if (state != null) xmlWriter.writeElement(XMLWriter.NS.CTI, "state", state);
            xmlWriter.writeElement(XMLWriter.NS.CTI, "country", country);
            if (envelopeAddress != null) {
                xmlWriter.writeElement(XMLWriter.NS.CTI, "envelopeAddress", envelopeAddress);
            }
            xmlWriter.endElement(XMLWriter.NS.CTI, POSTALADDRESS);
        } catch (SAXException ex) {
            throw new SerializationException(ex);
        }
    }
}

