/*
 * ContactPerson.java
 * 
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration;

import eu.europa.echa.reach.preregistration.xml.XMLWriter;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.SQLWarning;
import org.apache.log4j.Logger;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;

/*
 *
 * @author Csk Gbor
 */
public class ContactPerson {
    private static final Logger logger = Logger.getLogger(ContactPerson.class);
    
    public String id;
    public String title;
    public String firstName; //*
    public String lastName; //*
    public Organisation organisation;
    public String remarks;
    public ContactInfo contactInfo;
    
    public ContactPerson() {
    }
    
    
    public void serialize(XMLWriter xmlWriter, PreRegistration.Mode mode) throws SerializationException {
        try {
            final String CONTACTPERSON = "contactPerson";
            AttributesImpl attributes = new AttributesImpl();
            if (mode == PreRegistration.Mode.BULK) attributes.addAttribute("", "", "id", "", id);
            xmlWriter.startElement(XMLWriter.NS.PRG, CONTACTPERSON, attributes);
            if (title != null) xmlWriter.writeElement(XMLWriter.NS.CTI, "title", title);
            xmlWriter.writeElement(XMLWriter.NS.CTI, "firstName", firstName);
            xmlWriter.writeElement(XMLWriter.NS.CTI, "lastName", lastName);
            if (organisation != null) organisation.serialize(xmlWriter);
            if (remarks != null) {
                xmlWriter.writeElement(XMLWriter.NS.CTI, "remarks", remarks);
            }
            if (contactInfo != null) contactInfo.serialize(xmlWriter);
            xmlWriter.endElement(XMLWriter.NS.PRG, CONTACTPERSON);
        } catch (SAXException ex) {
            throw new SerializationException(ex);
        }
    }
    
}
