/*
 * SubstanceConstituentIdentity.java
 *
 * ECHA is providing program source code to facilitate the preparation of
 * pre-registration XML files. The code shall serve as example and
 * registrants are under no circumstances obliged to make use of this service
 * for submitting data to ECHA. In no event shall ECHA be liable for any
 * damages, direct, incidental or consequential (including through negligence
 * or otherwise) which may result from the use of the data provided, even if
 * ECHA has been advised of the possibility of such damages.
 * The users must assume the entire risk of using this source code.
 */

package eu.europa.echa.reach.preregistration;

import eu.europa.echa.reach.preregistration.xml.XMLWriter;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;

/**
 *
 * @author Csk Gbor
 */
public class SubstanceConstituentIdentity {
    public String ecNumber;
    public String casNumber;
    public String ecName;
    public String casName;
    public String iupacName;
    public String otherName;
    public String lang;
    
    public SubstanceConstituentIdentity() {
    }
    
    public void serialize(XMLWriter xmlWriter, PreRegistration.Mode mode) throws SerializationException {
        try {
            final String SUBSTANCECONSTITUENTIDENTITY = "SubstanceConstituentIdentity";
            if (mode == PreRegistration.Mode.BULK) {
                xmlWriter.startElement(XMLWriter.NS.SID, SUBSTANCECONSTITUENTIDENTITY);
                if (ecNumber != null) { //In BULK mode ecNumber is mandatory
                    AttributesImpl attributes = new AttributesImpl();
                    attributes.addAttribute("","","ecNumber","", ecNumber);
                    xmlWriter.writeElement(XMLWriter.NS.SID, "ECIdentity", attributes, null);
                }
                xmlWriter.endElement(XMLWriter.NS.SID, SUBSTANCECONSTITUENTIDENTITY);
            } else if (mode == PreRegistration.Mode.SIMPLE) {
                xmlWriter.startElement(XMLWriter.NS.SID, SUBSTANCECONSTITUENTIDENTITY);
                if (ecNumber != null) {
                    AttributesImpl attributes = new AttributesImpl();
                    attributes.addAttribute("","","ecNumber","", ecNumber);
                    xmlWriter.writeElement(XMLWriter.NS.SID, "ECIdentity", attributes, null);
                }
                if (casNumber != null) {
                    AttributesImpl attributes = new AttributesImpl();
                    attributes.addAttribute("","","casNumber","", casNumber);
                    xmlWriter.writeElement(XMLWriter.NS.SID, "CASIdentity", attributes, null);
                }
                
                if (ecName != null || casName != null || iupacName != null || otherName != null) {
                    final String CHEMICALNAMEIDENTITIES = "ChemicalNameIdentities";
                    xmlWriter.startElement(XMLWriter.NS.SID, CHEMICALNAMEIDENTITIES);
                    if (ecName != null) {
                        AttributesImpl attributes = new AttributesImpl();
                        attributes.addAttribute("","","type","", "EC");
                        if (lang != null) {
                            attributes.addAttribute("","","xml:lang","", lang);
                        }
                        xmlWriter.writeElement(XMLWriter.NS.SID, "ChemicalNameIdentity", attributes, ecName);
                    }
                    
                    if (casName != null) {
                        AttributesImpl attributes = new AttributesImpl();
                        attributes.addAttribute("","","type","", "CAS");
                        if (lang != null) {
                            attributes.addAttribute("","","xml:lang","", lang);
                        }
                        xmlWriter.writeElement(XMLWriter.NS.SID, "ChemicalNameIdentity", attributes, casName);
                    }
                    
                    if (iupacName != null) {
                        AttributesImpl attributes = new AttributesImpl();
                        attributes.addAttribute("","","type","", "IUPAC");
                        if (lang != null) {
                            attributes.addAttribute("","","xml:lang","", lang);
                        }
                        xmlWriter.writeElement(XMLWriter.NS.SID, "ChemicalNameIdentity", attributes, iupacName);
                    }
                    
                    if (otherName != null) {
                        AttributesImpl attributes = new AttributesImpl();
                        attributes.addAttribute("","","type","", "OTHER");
                        if (lang != null) {
                            attributes.addAttribute("","","xml:lang","", lang);
                        }
                        xmlWriter.writeElement(XMLWriter.NS.SID, "ChemicalNameIdentity", attributes, otherName);
                    }
                    xmlWriter.endElement(XMLWriter.NS.SID, CHEMICALNAMEIDENTITIES);
                }
                xmlWriter.endElement(XMLWriter.NS.SID, SUBSTANCECONSTITUENTIDENTITY);
            }
        } catch (SAXException ex) {
            throw new SerializationException(ex);
        }
    }

}
